@@ -761,9 +761,7 @@ func TestParseInetSpecForDifferentKeysFormatting(t *testing.T) {
 	}
 
 	for keysClauseName, keysClause := range keysClauses {
-		keysClause := keysClause
 		for allowClauseName, allowClause := range allowClauses {
-			allowClause := allowClause
 			testCaseName := fmt.Sprintf("%s_%s", keysClauseName, allowClauseName)
 			t.Run(testCaseName, func(t *testing.T) {
 				inetClause := fmt.Sprintf("inet 127.0.0.1 %s %s;", allowClause, keysClause)
@@ -792,6 +790,28 @@ func TestParseInetSpecForDifferentKeysFormatting(t *testing.T) {
 	}
 }
 
+// Test that the wildcard addresses are resolved to the localhost address.
+func TestParseInetSpecForDifferentWildcardAddresses(t *testing.T) {
+	// Arrange
+	addresses := []string{"*", "0.0.0.0", "::", "localhost"}
+
+	for _, address := range addresses {
+		inetClause := fmt.Sprintf("inet %s allow { };", address)
+
+		config := fmt.Sprintf(`
+			controls {
+				%s
+			};
+		`, inetClause)
+
+		// Act
+		address, _, _ := parseInetSpec(config, inetClause)
+
+		// Assert
+		require.Equal(t, "localhost", address)
+	}
+}
+
 // Test that the RNDC key is converted to string properly.
 func TestBind9RndcKeyString(t *testing.T) {
 	// Arrange
