@@ -283,6 +283,29 @@ func TestNewConfigFromMap(t *testing.T) {
 	require.Equal(t, "192.0.2.0/24", subnets[0].GetPrefix())
 }
 
+// Test getting raw configuration.
+func TestGetRawConfig(t *testing.T) {
+	// Set the original config.
+	var config Config
+	err := json.Unmarshal(testutil.AllKeysDHCPv4JSON, &config)
+	require.NoError(t, err)
+
+	// Extract the raw config.
+	rawConfig, err := config.GetRawConfig()
+	require.NoError(t, err)
+	require.NotNil(t, rawConfig)
+	require.Equal(t, config.Raw, rawConfig)
+
+	// Make sure it contains the top-level key.
+	require.Contains(t, rawConfig, "Dhcp4")
+
+	// Serialize it again and make sure it is equal to the original.
+	marshalled, err := json.Marshal(config)
+	require.NoError(t, err)
+
+	require.JSONEq(t, string(testutil.AllKeysDHCPv4JSON), string(marshalled))
+}
+
 // Test that DHCPv4 config is returned as a common data accessor.
 func TestGetCommonConfigAccessorDHCPv4(t *testing.T) {
 	cfg := &Config{
@@ -732,6 +755,80 @@ func TestGetDDNSParameters(t *testing.T) {
 	require.Equal(t, float32(0.55), *cfg.GetDDNSParameters().DDNSTTLPercent)
 }
 
+// Test that DHCP DDNS parameters are parsed and returned correctly.
+func TestGetDHCPDDNSParameters(t *testing.T) {
+	configStr := `{
+        "Dhcp4": {
+			"dhcp-ddns": {
+				"enable-updates": true,
+				"max-queue-size": 7,
+				"ncr-format": "JSON",
+				"ncr-protocol": "UDP",
+				"sender-ip": "192.0.2.1",
+				"sender-port": 8080,
+				"server-ip": "192.0.2.2",
+				"server-port": 8081
+			}
+		}
+	}`
+
+	cfg, err := NewConfig(configStr)
+	require.NoError(t, err)
+	require.NotNil(t, cfg)
+
+	require.NotNil(t, cfg.GetDHCPDDNSParameters())
+	require.NotNil(t, cfg.GetDHCPDDNSParameters().EnableUpdates)
+	require.True(t, *cfg.GetDHCPDDNSParameters().EnableUpdates)
+	require.NotNil(t, cfg.GetDHCPDDNSParameters().MaxQueueSize)
+	require.EqualValues(t, 7, *cfg.GetDHCPDDNSParameters().MaxQueueSize)
+	require.NotNil(t, cfg.GetDHCPDDNSParameters().NCRFormat)
+	require.Equal(t, "JSON", *cfg.GetDHCPDDNSParameters().NCRFormat)
+	require.NotNil(t, cfg.GetDHCPDDNSParameters().NCRProtocol)
+	require.EqualValues(t, "UDP", *cfg.GetDHCPDDNSParameters().NCRProtocol)
+	require.NotNil(t, cfg.GetDHCPDDNSParameters().SenderIP)
+	require.Equal(t, "192.0.2.1", *cfg.GetDHCPDDNSParameters().SenderIP)
+	require.NotNil(t, cfg.GetDHCPDDNSParameters().SenderPort)
+	require.EqualValues(t, 8080, *cfg.GetDHCPDDNSParameters().SenderPort)
+	require.NotNil(t, cfg.GetDHCPDDNSParameters().ServerIP)
+	require.Equal(t, "192.0.2.2", *cfg.GetDHCPDDNSParameters().ServerIP)
+	require.NotNil(t, cfg.GetDHCPDDNSParameters().ServerPort)
+	require.EqualValues(t, 8081, *cfg.GetDHCPDDNSParameters().ServerPort)
+}
+
+// Test that expiration lease processing parameters are parsed and returned correctly.
+func TestGetExpiredLeasesProcessingParameters(t *testing.T) {
+	configStr := `{
+        "Dhcp4": {
+			"expired-leases-processing": {
+				"flush-reclaimed-timer-wait-time": 15,
+				"hold-reclaimed-time": 3,
+				"max-reclaim-leases": 18,
+				"max-reclaim-time": 123,
+				"reclaim-timer-wait-time": 11,
+				"unwarned-reclaim-cycles": 1
+			}
+		}
+	}`
+
+	cfg, err := NewConfig(configStr)
+	require.NoError(t, err)
+	require.NotNil(t, cfg)
+
+	require.NotNil(t, cfg.GetExpiredLeasesProcessingParameters())
+	require.NotNil(t, cfg.GetExpiredLeasesProcessingParameters().FlushReclaimedTimerWaitTime)
+	require.EqualValues(t, 15, *cfg.GetExpiredLeasesProcessingParameters().FlushReclaimedTimerWaitTime)
+	require.NotNil(t, cfg.GetExpiredLeasesProcessingParameters().HoldReclaimedTime)
+	require.EqualValues(t, 3, *cfg.GetExpiredLeasesProcessingParameters().HoldReclaimedTime)
+	require.NotNil(t, cfg.GetExpiredLeasesProcessingParameters().MaxReclaimLeases)
+	require.EqualValues(t, 18, *cfg.GetExpiredLeasesProcessingParameters().MaxReclaimLeases)
+	require.NotNil(t, cfg.GetExpiredLeasesProcessingParameters().MaxReclaimTime)
+	require.EqualValues(t, 123, *cfg.GetExpiredLeasesProcessingParameters().MaxReclaimTime)
+	require.NotNil(t, cfg.GetExpiredLeasesProcessingParameters().ReclaimTimerWaitTime)
+	require.EqualValues(t, 11, *cfg.GetExpiredLeasesProcessingParameters().ReclaimTimerWaitTime)
+	require.NotNil(t, cfg.GetExpiredLeasesProcessingParameters().UnwarnedReclaimCycles)
+	require.EqualValues(t, 1, *cfg.GetExpiredLeasesProcessingParameters().UnwarnedReclaimCycles)
+}
+
 // Test that hostname char parameters are parsed and returned correctly.
 func TestGetHostnameCharParameters(t *testing.T) {
 	configStr := `{
@@ -1701,3 +1798,677 @@ func TestGetDHCPOptions6(t *testing.T) {
 	require.Equal(t, "nis-servers", options[1].Name)
 	require.Equal(t, dhcpmodel.DHCPv6OptionSpace, options[0].Space)
 }
+
+// Test merging a partial config into current config.
+func TestMergeConfig(t *testing.T) {
+	source1 := `{
+		"Dhcp4": {
+			"allocator": "iterative",
+			"valid-lifetime": 123,
+			"host-identifiers": [ "hw-address", "circuit-id" ],
+			"expired-leases-processing": {
+				"reclaim-timer-wait-time": 5,
+				"max-reclaim-leases": 0
+			},
+			"hooks-libraries": [
+				{
+					"library": "/tmp/hooks-library.so"
+				}
+			]
+		},
+		"hash": "01020304"
+	}`
+	source2 := `{
+		"Dhcp4": {
+			"allocator": "flq",
+			"boot-file-name": "/tmp/filename",
+			"expired-leases-processing": {
+				"max-reclaim-leases": 12,
+				"max-reclaim-time": 7
+			}
+		},
+		"hash": "02030405"
+	}`
+	config1, err := NewConfig(source1)
+	require.NoError(t, err)
+	require.NotNil(t, config1)
+
+	config2, err := NewConfig(source2)
+	require.NoError(t, err)
+	require.NotNil(t, config2)
+
+	config1.Merge(config2)
+	require.NotNil(t, config1)
+
+	marshalled, err := json.Marshal(config1)
+	require.NoError(t, err)
+	require.JSONEq(t, `{
+		"Dhcp4": {
+			"allocator": "flq",
+			"boot-file-name": "/tmp/filename",
+			"valid-lifetime": 123,
+			"host-identifiers": [ "hw-address", "circuit-id" ],
+			"expired-leases-processing": {
+				"reclaim-timer-wait-time": 5,
+				"max-reclaim-leases": 12,
+				"max-reclaim-time": 7
+			},
+			"hooks-libraries": [
+				{
+					"library": "/tmp/hooks-library.so"
+				}
+			]
+		}
+	}`, string(marshalled))
+
+	require.NotNil(t, config1.GetAllocator())
+	require.Equal(t, "flq", *config1.GetAllocator())
+
+	require.NotNil(t, config1.GetBootFileName())
+	require.Equal(t, "/tmp/filename", *config1.GetBootFileName())
+
+	require.NotNil(t, config1.GetValidLifetimeParameters().ValidLifetime)
+	require.EqualValues(t, 123, *config1.GetValidLifetimeParameters().ValidLifetime)
+}
+
+// Test merging a settable config into current config.
+func TestMergeSettableConfig(t *testing.T) {
+	source1 := `{
+		"Dhcp4": {
+			"allocator": "iterative",
+			"valid-lifetime": 123,
+			"host-reservation-identifiers": [ "hw-address", "circuit-id" ],
+			"expired-leases-processing": {
+				"reclaim-timer-wait-time": 5,
+				"max-reclaim-leases": 0
+			},
+			"hooks-libraries": [
+				{
+					"library": "/tmp/hooks-library.so"
+				}
+			]
+		},
+		"hash": "01020304"
+	}`
+	config1, err := NewConfig(source1)
+	require.NoError(t, err)
+	require.NotNil(t, config1)
+
+	config2 := NewSettableDHCPv4Config()
+	require.NoError(t, err)
+
+	config2.SetAllocator(storkutil.Ptr("flq"))
+	config2.SetELPMaxReclaimLeases(storkutil.Ptr(int64(12)))
+	config2.SetELPMaxReclaimTime(storkutil.Ptr(int64(7)))
+	config2.SetDHCPDDNSEnableUpdates(storkutil.Ptr(true))
+	config2.SetDHCPDDNSMaxQueueSize(nil)
+	config2.SetValidLifetime(nil)
+
+	config1.Merge(config2)
+	require.NotNil(t, config1)
+
+	marshalled, err := json.Marshal(config1)
+	require.NoError(t, err)
+	require.JSONEq(t, `{
+		"Dhcp4": {
+			"allocator": "flq",
+			"host-reservation-identifiers": [ "hw-address", "circuit-id" ],
+			"dhcp-ddns": {
+				"enable-updates": true
+			},
+			"expired-leases-processing": {
+				"reclaim-timer-wait-time": 5,
+				"max-reclaim-leases": 12,
+				"max-reclaim-time": 7
+			},
+			"hooks-libraries": [
+				{
+					"library": "/tmp/hooks-library.so"
+				}
+			]
+		}
+	}`, string(marshalled))
+
+	require.NotNil(t, config1.GetAllocator())
+	require.Equal(t, "flq", *config1.GetAllocator())
+
+	require.ElementsMatch(t, config1.GetGlobalReservationParameters().HostReservationIdentifiers, []string{"hw-address", "circuit-id"})
+
+	d2 := config1.GetDHCPDDNSParameters()
+	require.NotNil(t, d2)
+	require.NotNil(t, d2.EnableUpdates)
+	require.True(t, *d2.EnableUpdates)
+	require.Nil(t, d2.MaxQueueSize)
+
+	elp := config1.GetExpiredLeasesProcessingParameters()
+	require.NotNil(t, elp)
+	require.NotNil(t, elp.ReclaimTimerWaitTime)
+	require.EqualValues(t, 5, *elp.ReclaimTimerWaitTime)
+	require.NotNil(t, elp.MaxReclaimLeases)
+	require.EqualValues(t, 12, *elp.MaxReclaimLeases)
+	require.NotNil(t, elp.MaxReclaimTime)
+	require.EqualValues(t, 7, *elp.MaxReclaimTime)
+
+	require.Nil(t, config1.GetValidLifetimeParameters().ValidLifetime)
+}
+
+// Tests instantiating settable Kea Control Agent configuration.
+func TestNewSettableCtrlAgentConfig(t *testing.T) {
+	settableConfig := NewSettableCtrlAgentConfig()
+	require.NotNil(t, settableConfig)
+	require.NotNil(t, settableConfig.SettableCtrlAgentConfig)
+}
+
+// Tests instantiating settable D2 configuration.
+func TestNewSettableD2Config(t *testing.T) {
+	settableConfig := NewSettableD2Config()
+	require.NotNil(t, settableConfig)
+	require.NotNil(t, settableConfig.SettableD2Config)
+}
+
+// Tests instantiating settable DHCPv4 configuration.
+func TestNewSettableDHCPv4Config(t *testing.T) {
+	settableConfig := NewSettableDHCPv4Config()
+	require.NotNil(t, settableConfig)
+	require.NotNil(t, settableConfig.SettableDHCPv4Config)
+}
+
+// Tests instantiating settable DHCPv6 configuration.
+func TestNewSettableDHCPv6Config(t *testing.T) {
+	settableConfig := NewSettableDHCPv6Config()
+	require.NotNil(t, settableConfig)
+	require.NotNil(t, settableConfig.SettableDHCPv6Config)
+}
+
+// Test getting raw configuration.
+func TestGetRawSettableConfig(t *testing.T) {
+	// Set the original config.
+	config := NewSettableDHCPv4Config()
+	err := config.SetValidLifetime(storkutil.Ptr(int64(1111)))
+	require.NoError(t, err)
+
+	// Extract the raw config.
+	rawConfig, err := config.GetRawConfig()
+	require.NoError(t, err)
+	require.NotNil(t, rawConfig)
+
+	// Make sure it contains the top-level key.
+	require.Contains(t, rawConfig, "Dhcp4")
+
+	// Serialize it again and make sure it is equal to the original.
+	marshalled, err := json.Marshal(config)
+	require.NoError(t, err)
+
+	require.JSONEq(t, `{
+		"Dhcp4": {
+			"valid-lifetime": 1111
+		}
+	}`, string(marshalled))
+}
+
+// Test setting various DHCPv4 global configuration parameters.
+func TestSettingDHCPv4GlobalParameters(t *testing.T) {
+	config := NewSettableDHCPv4Config()
+
+	err := config.SetAllocator(storkutil.Ptr("flq"))
+	require.NoError(t, err)
+
+	err = config.SetCacheThreshold(storkutil.Ptr(float32(0.2)))
+	require.NoError(t, err)
+
+	err = config.SetDDNSSendUpdates(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDDNSOverrideNoUpdate(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDDNSOverrideClientUpdate(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDDNSReplaceClientName(storkutil.Ptr("never"))
+	require.NoError(t, err)
+
+	err = config.SetDDNSGeneratedPrefix(storkutil.Ptr("myhost.example.org"))
+	require.NoError(t, err)
+
+	err = config.SetDDNSQualifyingSuffix(storkutil.Ptr("example.org"))
+	require.NoError(t, err)
+
+	err = config.SetDDNSUpdateOnRenew(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDDNSUseConflictResolution(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDDNSConflictResolutionMode(storkutil.Ptr("check-with-dhcid"))
+	require.NoError(t, err)
+
+	err = config.SetDDNSTTLPercent(storkutil.Ptr(float32(0.1)))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSEnableUpdates(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSMaxQueueSize(storkutil.Ptr(int64(100)))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSNCRFormat(storkutil.Ptr("JSON"))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSNCRProtocol(storkutil.Ptr("UDP"))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSSenderIP(storkutil.Ptr("192.0.2.1"))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSSenderPort(storkutil.Ptr(int64(8080)))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSServerIP(storkutil.Ptr("192.0.2.2"))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSServerPort(storkutil.Ptr(int64(8081)))
+	require.NoError(t, err)
+
+	err = config.SetELPFlushReclaimedTimerWaitTime(storkutil.Ptr(int64(111)))
+	require.NoError(t, err)
+
+	err = config.SetELPHoldReclaimedTime(storkutil.Ptr(int64(111)))
+	require.NoError(t, err)
+
+	err = config.SetELPMaxReclaimLeases(storkutil.Ptr(int64(111)))
+	require.NoError(t, err)
+
+	err = config.SetELPMaxReclaimTime(storkutil.Ptr(int64(2)))
+	require.NoError(t, err)
+
+	err = config.SetELPReclaimTimerWaitTime(storkutil.Ptr(int64(3)))
+	require.NoError(t, err)
+
+	err = config.SetELPUnwarnedReclaimCycles(storkutil.Ptr(int64(10)))
+	require.NoError(t, err)
+
+	err = config.SetReservationsGlobal(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetReservationsInSubnet(storkutil.Ptr(false))
+	require.NoError(t, err)
+
+	err = config.SetReservationsOutOfPool(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetEarlyGlobalReservationsLookup(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetHostReservationIdentifiers([]string{"hw-address", "client-id"})
+	require.NoError(t, err)
+
+	err = config.SetAuthoritative(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetEchoClientID(storkutil.Ptr(false))
+	require.NoError(t, err)
+
+	err = config.SetDHCPOptions([]SingleOptionData{
+		{
+			AlwaysSend: true,
+			Code:       42,
+			CSVFormat:  true,
+			Data:       "foo",
+			Name:       "forty-two",
+			Space:      "dhcp4",
+		},
+		{
+			Code:  24,
+			Data:  "bar",
+			Name:  "twenty-four",
+			Space: "dhcp4",
+		},
+	})
+	require.NoError(t, err)
+
+	serializedConfig, err := config.GetSerializedConfig()
+	require.NoError(t, err)
+
+	require.JSONEq(t, `{
+		"Dhcp4": {
+			"cache-threshold": 0.2,
+			"ddns-generated-prefix": "myhost.example.org",
+			"ddns-override-client-update": true,
+			"ddns-override-no-update": true,
+			"ddns-qualifying-suffix": "example.org",
+			"ddns-replace-client-name": "never",
+			"ddns-send-updates": true,
+			"ddns-update-on-renew": true,
+			"ddns-use-conflict-resolution": true,
+			"ddns-conflict-resolution-mode": "check-with-dhcid",
+			"ddns-ttl-percent": 0.1,
+			"dhcp-ddns": {
+				"enable-updates": true,
+				"max-queue-size": 100,
+				"ncr-format": "JSON",
+				"ncr-protocol": "UDP",
+				"sender-ip": "192.0.2.1",
+				"sender-port": 8080,
+				"server-ip": "192.0.2.2",
+				"server-port": 8081
+			},
+			"early-global-reservations-lookup": true,
+			"host-reservation-identifiers": [
+				"hw-address",
+				"client-id"
+			],
+			"reservations-global": true,
+			"reservations-in-subnet": false,
+			"reservations-out-of-pool": true,
+			"allocator": "flq",
+			"expired-leases-processing": {
+				"flush-reclaimed-timer-wait-time": 111,
+				"hold-reclaimed-time": 111,
+				"max-reclaim-leases": 111,
+				"max-reclaim-time": 2,
+				"reclaim-timer-wait-time": 3,
+				"unwarned-reclaim-cycles": 10
+			},
+			"authoritative": true,
+			"echo-client-id": false,
+			"option-data": [
+				{
+					"always-send": true,
+					"code": 42,
+					"csv-format": true,
+					"data": "foo",
+					"name": "forty-two",
+					"space": "dhcp4"
+				},
+				{
+					"code": 24,
+					"csv-format": false,
+					"data": "bar",
+					"name": "twenty-four",
+					"space": "dhcp4"
+				}
+			]
+		}
+	}`, serializedConfig)
+}
+
+// Test setting DHCP DDNS for the DHCPv4 server.
+func TestSettingDHCPv4DHCPDDNS(t *testing.T) {
+	config := NewSettableDHCPv4Config()
+
+	dhcpDDNS := &SettableDHCPDDNS{
+		EnableUpdates: storkutil.NewNullableFromValue(true),
+		ServerIP:      storkutil.NewNullableFromValue("192.0.2.1"),
+		ServerPort:    storkutil.NewNullableFromValue(int64(8080)),
+		SenderIP:      storkutil.NewNullableFromValue("192.0.2.2"),
+		SenderPort:    storkutil.NewNullableFromValue(int64(8081)),
+		MaxQueueSize:  storkutil.NewNullableFromValue(int64(100)),
+		NCRProtocol:   storkutil.NewNullableFromValue("UDP"),
+		NCRFormat:     storkutil.NewNullableFromValue("JSON"),
+	}
+	err := config.SetDHCPDDNS(dhcpDDNS)
+	require.NoError(t, err)
+
+	serializedConfig, err := config.GetSerializedConfig()
+	require.NoError(t, err)
+
+	require.JSONEq(t, `{
+		"Dhcp4": {
+			"dhcp-ddns": {
+				"enable-updates": true,
+				"server-ip": "192.0.2.1",
+				"server-port": 8080,
+				"sender-ip": "192.0.2.2",
+				"sender-port": 8081,
+				"max-queue-size": 100,
+				"ncr-format": "JSON",
+				"ncr-protocol": "UDP"
+			}
+		}
+	}`, serializedConfig)
+}
+
+// Test setting expired leases processing for DHCPv4 server.
+func TestSettingDHCPv4ExpiredLeasesProcessing(t *testing.T) {
+	config := NewSettableDHCPv4Config()
+
+	expiredLeasesProcessing := &SettableExpiredLeasesProcessing{
+		FlushReclaimedTimerWaitTime: storkutil.NewNullableFromValue(int64(1)),
+		HoldReclaimedTime:           storkutil.NewNullableFromValue(int64(2)),
+		MaxReclaimLeases:            storkutil.NewNullableFromValue(int64(3)),
+		MaxReclaimTime:              storkutil.NewNullableFromValue(int64(4)),
+		ReclaimTimerWaitTime:        storkutil.NewNullableFromValue(int64(5)),
+		UnwarnedReclaimCycles:       storkutil.NewNullableFromValue(int64(6)),
+	}
+	err := config.SetExpiredLeasesProcessing(expiredLeasesProcessing)
+	require.NoError(t, err)
+
+	serializedConfig, err := config.GetSerializedConfig()
+	require.NoError(t, err)
+
+	require.JSONEq(t, `{
+		"Dhcp4": {
+			"expired-leases-processing": {
+				"flush-reclaimed-timer-wait-time": 1,
+				"hold-reclaimed-time": 2,
+				"max-reclaim-leases": 3,
+				"max-reclaim-time": 4,
+				"reclaim-timer-wait-time": 5,
+				"unwarned-reclaim-cycles": 6
+			}
+		}
+	}`, serializedConfig)
+}
+
+// Test setting various DHCPv6 global configuration parameters.
+func TestSettingDHCPv6GlobalParameters(t *testing.T) {
+	config := NewSettableDHCPv6Config()
+
+	err := config.SetAllocator(storkutil.Ptr("flq"))
+	require.NoError(t, err)
+
+	err = config.SetCacheThreshold(storkutil.Ptr(float32(0.2)))
+	require.NoError(t, err)
+
+	err = config.SetDDNSSendUpdates(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDDNSOverrideNoUpdate(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDDNSOverrideClientUpdate(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDDNSReplaceClientName(storkutil.Ptr("never"))
+	require.NoError(t, err)
+
+	err = config.SetDDNSGeneratedPrefix(storkutil.Ptr("myhost.example.org"))
+	require.NoError(t, err)
+
+	err = config.SetDDNSQualifyingSuffix(storkutil.Ptr("example.org"))
+	require.NoError(t, err)
+
+	err = config.SetDDNSUpdateOnRenew(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDDNSUseConflictResolution(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDDNSTTLPercent(storkutil.Ptr(float32(0.1)))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSEnableUpdates(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSMaxQueueSize(storkutil.Ptr(int64(100)))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSNCRFormat(storkutil.Ptr("JSON"))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSNCRProtocol(storkutil.Ptr("UDP"))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSSenderIP(storkutil.Ptr("2001:db8:1::1"))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSSenderPort(storkutil.Ptr(int64(8080)))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSServerIP(storkutil.Ptr("2001:db8:1::2"))
+	require.NoError(t, err)
+
+	err = config.SetDHCPDDNSServerPort(storkutil.Ptr(int64(8081)))
+	require.NoError(t, err)
+
+	err = config.SetELPFlushReclaimedTimerWaitTime(storkutil.Ptr(int64(111)))
+	require.NoError(t, err)
+
+	err = config.SetELPHoldReclaimedTime(storkutil.Ptr(int64(111)))
+	require.NoError(t, err)
+
+	err = config.SetELPMaxReclaimLeases(storkutil.Ptr(int64(111)))
+	require.NoError(t, err)
+
+	err = config.SetELPMaxReclaimTime(storkutil.Ptr(int64(2)))
+	require.NoError(t, err)
+
+	err = config.SetELPReclaimTimerWaitTime(storkutil.Ptr(int64(3)))
+	require.NoError(t, err)
+
+	err = config.SetELPUnwarnedReclaimCycles(storkutil.Ptr(int64(10)))
+	require.NoError(t, err)
+
+	err = config.SetReservationsGlobal(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetReservationsInSubnet(storkutil.Ptr(false))
+	require.NoError(t, err)
+
+	err = config.SetReservationsOutOfPool(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetEarlyGlobalReservationsLookup(storkutil.Ptr(true))
+	require.NoError(t, err)
+
+	err = config.SetHostReservationIdentifiers([]string{"hw-address", "client-id"})
+	require.NoError(t, err)
+
+	err = config.SetPDAllocator(storkutil.Ptr("random"))
+	require.NoError(t, err)
+
+	serializedConfig, err := config.GetSerializedConfig()
+	require.NoError(t, err)
+
+	require.JSONEq(t, `{
+		"Dhcp6": {
+			"cache-threshold": 0.2,
+			"ddns-generated-prefix": "myhost.example.org",
+			"ddns-override-client-update": true,
+			"ddns-override-no-update": true,
+			"ddns-qualifying-suffix": "example.org",
+			"ddns-replace-client-name": "never",
+			"ddns-send-updates": true,
+			"ddns-update-on-renew": true,
+			"ddns-use-conflict-resolution": true,
+			"ddns-ttl-percent": 0.1,
+			"dhcp-ddns": {
+				"enable-updates": true,
+				"max-queue-size": 100,
+				"ncr-format": "JSON",
+				"ncr-protocol": "UDP",
+				"sender-ip": "2001:db8:1::1",
+				"sender-port": 8080,
+				"server-ip": "2001:db8:1::2",
+				"server-port": 8081
+			},
+			"early-global-reservations-lookup": true,
+			"host-reservation-identifiers": [
+				"hw-address",
+				"client-id"
+			],
+			"reservations-global": true,
+			"reservations-in-subnet": false,
+			"reservations-out-of-pool": true,
+			"allocator": "flq",
+			"expired-leases-processing": {
+				"flush-reclaimed-timer-wait-time": 111,
+				"hold-reclaimed-time": 111,
+				"max-reclaim-leases": 111,
+				"max-reclaim-time": 2,
+				"reclaim-timer-wait-time": 3,
+				"unwarned-reclaim-cycles": 10
+			},
+			"pd-allocator": "random"
+		}
+	}`, serializedConfig)
+}
+
+// Test setting DHCP DDNS for the DHCPv6 server.
+func TestSettingDHCPv6DHCPDDNS(t *testing.T) {
+	config := NewSettableDHCPv6Config()
+
+	dhcpDDNS := &SettableDHCPDDNS{
+		EnableUpdates: storkutil.NewNullableFromValue(true),
+		ServerIP:      storkutil.NewNullableFromValue("2001:db8:1::1"),
+		ServerPort:    storkutil.NewNullableFromValue(int64(8080)),
+		SenderIP:      storkutil.NewNullableFromValue("2001:db8:1::2"),
+		SenderPort:    storkutil.NewNullableFromValue(int64(8081)),
+		MaxQueueSize:  storkutil.NewNullableFromValue(int64(100)),
+		NCRProtocol:   storkutil.NewNullableFromValue("UDP"),
+		NCRFormat:     storkutil.NewNullableFromValue("JSON"),
+	}
+	err := config.SetDHCPDDNS(dhcpDDNS)
+	require.NoError(t, err)
+
+	serializedConfig, err := config.GetSerializedConfig()
+	require.NoError(t, err)
+
+	require.JSONEq(t, `{
+		"Dhcp6": {
+			"dhcp-ddns": {
+				"enable-updates": true,
+				"server-ip": "2001:db8:1::1",
+				"server-port": 8080,
+				"sender-ip": "2001:db8:1::2",
+				"sender-port": 8081,
+				"max-queue-size": 100,
+				"ncr-format": "JSON",
+				"ncr-protocol": "UDP"
+			}
+		}
+	}`, serializedConfig)
+}
+
+// Test setting expired leases processing for DHCPv6 server.
+func TestSettingDHCPv6ExpiredLeasesProcessing(t *testing.T) {
+	config := NewSettableDHCPv6Config()
+
+	expiredLeasesProcessing := &SettableExpiredLeasesProcessing{
+		FlushReclaimedTimerWaitTime: storkutil.NewNullableFromValue(int64(6)),
+		HoldReclaimedTime:           storkutil.NewNullableFromValue(int64(5)),
+		MaxReclaimLeases:            storkutil.NewNullableFromValue(int64(4)),
+		MaxReclaimTime:              storkutil.NewNullableFromValue(int64(3)),
+		ReclaimTimerWaitTime:        storkutil.NewNullableFromValue(int64(2)),
+		UnwarnedReclaimCycles:       storkutil.NewNullableFromValue(int64(1)),
+	}
+	err := config.SetExpiredLeasesProcessing(expiredLeasesProcessing)
+	require.NoError(t, err)
+
+	serializedConfig, err := config.GetSerializedConfig()
+	require.NoError(t, err)
+
+	require.JSONEq(t, `{
+		"Dhcp6": {
+			"expired-leases-processing": {
+				"flush-reclaimed-timer-wait-time": 6,
+				"hold-reclaimed-time": 5,
+				"max-reclaim-leases": 4,
+				"max-reclaim-time": 3,
+				"reclaim-timer-wait-time": 2,
+				"unwarned-reclaim-cycles": 1
+			}
+		}
+	}`, serializedConfig)
+}
