@@ -18,6 +18,7 @@ import (
 	"isc.org/stork"
 	"isc.org/stork/agent"
 	"isc.org/stork/hooks"
+	"isc.org/stork/profiler"
 	storkutil "isc.org/stork/util"
 )
 
@@ -505,6 +506,9 @@ func isHelpRequest(err error) bool {
 
 // Parses the command line arguments and runs the specific Stork Agent command.
 func runApp(reload bool) error {
+	profilerShutdown := profiler.Start(profiler.AgentProfilerPort)
+	defer profilerShutdown()
+
 	generalSettings, registerSettings, err := parseArgs()
 	if err != nil {
 		if isHelpRequest(err) {
@@ -520,9 +524,9 @@ func runApp(reload bool) error {
 		}
 
 		if generalSettings.ServerURL != "" && generalSettings.Host == "0.0.0.0" {
-			log.Errorf("Registration in Stork Server cannot be made because agent host address is not provided")
-			log.Fatalf("Use --host option or the STORK_AGENT_HOST environment variable")
-			return nil
+			err := errors.New("registration in Stork Server cannot be made because agent host address is not provided")
+			log.WithError(err).Error("Use --host option or the STORK_AGENT_HOST environment variable")
+			return err
 		}
 
 		return runAgent(generalSettings, reload)
@@ -533,8 +537,7 @@ func runApp(reload bool) error {
 		return nil
 	}
 
-	log.Fatalf("Unknown command specified")
-	return nil
+	return errors.New("provided CLI arguments were unexpected")
 }
 
 // Main stork-agent function.
