@@ -54,12 +54,13 @@ func TestFileServerMiddleware(t *testing.T) {
 
 // Check if InnerMiddleware works.
 func TestInnerMiddleware(t *testing.T) {
-	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
+	db, settings, teardown := dbtest.SetupDatabaseTestCase(t)
 	defer teardown()
-	rapi, err := NewRestAPI(dbSettings, db)
+	rapi, err := NewRestAPI(db, settings)
 	require.NoError(t, err)
-	sm, err := dbsession.NewSessionMgr(rapi.DBSettings)
+	sm, err := dbsession.NewSessionMgr(db)
 	require.NoError(t, err)
+	defer sm.Close()
 	rapi.SessionManager = sm
 
 	handler := rapi.InnerMiddleware(nil)
