@@ -254,6 +254,12 @@ func TestGetSharedNetwork4(t *testing.T) {
 	// ddns-use-conflict-resolution
 	require.NotNil(t, networkParams.DdnsUseConflictResolution)
 	require.True(t, *networkParams.DdnsUseConflictResolution)
+	// ddns-conflict-resolution-mode
+	require.NotNil(t, networkParams.DdnsConflictResolutionMode)
+	require.Equal(t, "check-with-dhcid", *networkParams.DdnsConflictResolutionMode)
+	// ddns-ttl-percent
+	require.NotNil(t, networkParams.DdnsTTLPercent)
+	require.EqualValues(t, float32(0.65), *networkParams.DdnsTTLPercent)
 	// hostname-char-replacement
 	require.NotNil(t, networkParams.HostnameCharReplacement)
 	require.Equal(t, "x", *networkParams.HostnameCharReplacement)
@@ -368,6 +374,9 @@ func TestGetSharedNetwork4(t *testing.T) {
 	// ddns-use-conflict-resolution
 	require.NotNil(t, globalParams.DdnsUseConflictResolution)
 	require.True(t, *globalParams.DdnsUseConflictResolution)
+	// ddns-conflict-resolution-mode
+	require.NotNil(t, networkParams.DdnsConflictResolutionMode)
+	require.Equal(t, "check-with-dhcid", *networkParams.DdnsConflictResolutionMode)
 	// hostname-char-replacement
 	require.NotNil(t, globalParams.HostnameCharReplacement)
 	require.Equal(t, "x", *globalParams.HostnameCharReplacement)
@@ -795,14 +804,16 @@ func TestCreateSharedNetwork4BeginSubmit(t *testing.T) {
 				RequireClientClasses: []string{"bar"},
 			},
 			KeaConfigDdnsParameters: models.KeaConfigDdnsParameters{
-				DdnsGeneratedPrefix:       storkutil.Ptr("abc"),
-				DdnsOverrideClientUpdate:  storkutil.Ptr(true),
-				DdnsOverrideNoUpdate:      storkutil.Ptr(false),
-				DdnsQualifyingSuffix:      storkutil.Ptr("example.org"),
-				DdnsReplaceClientName:     storkutil.Ptr("never"),
-				DdnsSendUpdates:           storkutil.Ptr(true),
-				DdnsUpdateOnRenew:         storkutil.Ptr(true),
-				DdnsUseConflictResolution: storkutil.Ptr(true),
+				DdnsGeneratedPrefix:        storkutil.Ptr("abc"),
+				DdnsOverrideClientUpdate:   storkutil.Ptr(true),
+				DdnsOverrideNoUpdate:       storkutil.Ptr(false),
+				DdnsQualifyingSuffix:       storkutil.Ptr("example.org"),
+				DdnsReplaceClientName:      storkutil.Ptr("never"),
+				DdnsSendUpdates:            storkutil.Ptr(true),
+				DdnsUpdateOnRenew:          storkutil.Ptr(true),
+				DdnsUseConflictResolution:  storkutil.Ptr(true),
+				DdnsConflictResolutionMode: storkutil.Ptr("check-with-dhcid"),
+				DdnsTTLPercent:             storkutil.Ptr(float32(0.65)),
 			},
 			KeaConfigFourOverSixParameters: models.KeaConfigFourOverSixParameters{
 				FourOverSixInterface:   storkutil.Ptr("eth0"),
@@ -911,6 +922,8 @@ func TestCreateSharedNetwork4BeginSubmit(t *testing.T) {
 								"ddns-send-updates": true,
 								"ddns-update-on-renew": true,
 								"ddns-use-conflict-resolution": true,
+								"ddns-conflict-resolution-mode": "check-with-dhcid",
+								"ddns-ttl-percent": 0.65,
 								"hostname-char-replacement": "a",
 								"hostname-char-set": "b",
 								"reservation-mode": "in-pool",
@@ -1005,6 +1018,8 @@ func TestCreateSharedNetwork4BeginSubmit(t *testing.T) {
 		require.True(t, *lsn.KeaParameters.DDNSUpdateOnRenew)
 		require.NotNil(t, lsn.KeaParameters.DDNSUseConflictResolution)
 		require.True(t, *lsn.KeaParameters.DDNSUseConflictResolution)
+		require.NotNil(t, *lsn.KeaParameters.DDNSTTLPercent)
+		require.EqualValues(t, float32(0.65), *lsn.KeaParameters.DDNSTTLPercent)
 		require.NotNil(t, lsn.KeaParameters.HostnameCharReplacement)
 		require.Equal(t, "a", *lsn.KeaParameters.HostnameCharReplacement)
 		require.NotNil(t, lsn.KeaParameters.HostnameCharSet)
@@ -1516,14 +1531,15 @@ func TestUpdateSharedNetwork4BeginSubmit(t *testing.T) {
 				RequireClientClasses: []string{"bar"},
 			},
 			KeaConfigDdnsParameters: models.KeaConfigDdnsParameters{
-				DdnsGeneratedPrefix:       storkutil.Ptr("abc"),
-				DdnsOverrideClientUpdate:  storkutil.Ptr(true),
-				DdnsOverrideNoUpdate:      storkutil.Ptr(false),
-				DdnsQualifyingSuffix:      storkutil.Ptr("example.org"),
-				DdnsReplaceClientName:     storkutil.Ptr("never"),
-				DdnsSendUpdates:           storkutil.Ptr(true),
-				DdnsUpdateOnRenew:         storkutil.Ptr(true),
-				DdnsUseConflictResolution: storkutil.Ptr(true),
+				DdnsGeneratedPrefix:        storkutil.Ptr("abc"),
+				DdnsOverrideClientUpdate:   storkutil.Ptr(true),
+				DdnsOverrideNoUpdate:       storkutil.Ptr(false),
+				DdnsQualifyingSuffix:       storkutil.Ptr("example.org"),
+				DdnsReplaceClientName:      storkutil.Ptr("never"),
+				DdnsSendUpdates:            storkutil.Ptr(true),
+				DdnsUpdateOnRenew:          storkutil.Ptr(true),
+				DdnsUseConflictResolution:  storkutil.Ptr(true),
+				DdnsConflictResolutionMode: storkutil.Ptr("check-with-dhcid"),
 			},
 			KeaConfigFourOverSixParameters: models.KeaConfigFourOverSixParameters{
 				FourOverSixInterface:   storkutil.Ptr("eth0"),
@@ -1686,6 +1702,7 @@ func TestUpdateSharedNetwork4BeginSubmit(t *testing.T) {
 								"ddns-send-updates": true,
 								"ddns-update-on-renew": true,
 								"ddns-use-conflict-resolution": true,
+								"ddns-conflict-resolution-mode": "check-with-dhcid",
 								"hostname-char-replacement": "a",
 								"hostname-char-set": "b",
 								"reservation-mode": "in-pool",
