@@ -29,14 +29,16 @@ func convertGlobalSubnetParametersToRestAPI(cfg *dbmodel.KeaConfig) *models.KeaC
 			CacheMaxAge:    cfg.GetCacheParameters().CacheMaxAge,
 		},
 		KeaConfigDdnsParameters: models.KeaConfigDdnsParameters{
-			DdnsGeneratedPrefix:       storkutil.NullifyEmptyString(cfg.GetDDNSParameters().DDNSGeneratedPrefix),
-			DdnsOverrideClientUpdate:  cfg.GetDDNSParameters().DDNSOverrideClientUpdate,
-			DdnsOverrideNoUpdate:      cfg.GetDDNSParameters().DDNSOverrideNoUpdate,
-			DdnsQualifyingSuffix:      storkutil.NullifyEmptyString(cfg.GetDDNSParameters().DDNSQualifyingSuffix),
-			DdnsReplaceClientName:     storkutil.NullifyEmptyString(cfg.GetDDNSParameters().DDNSReplaceClientName),
-			DdnsSendUpdates:           cfg.GetDDNSParameters().DDNSSendUpdates,
-			DdnsUpdateOnRenew:         cfg.GetDDNSParameters().DDNSUpdateOnRenew,
-			DdnsUseConflictResolution: cfg.GetDDNSParameters().DDNSUseConflictResolution,
+			DdnsGeneratedPrefix:        storkutil.NullifyEmptyString(cfg.GetDDNSParameters().DDNSGeneratedPrefix),
+			DdnsOverrideClientUpdate:   cfg.GetDDNSParameters().DDNSOverrideClientUpdate,
+			DdnsOverrideNoUpdate:       cfg.GetDDNSParameters().DDNSOverrideNoUpdate,
+			DdnsQualifyingSuffix:       storkutil.NullifyEmptyString(cfg.GetDDNSParameters().DDNSQualifyingSuffix),
+			DdnsReplaceClientName:      storkutil.NullifyEmptyString(cfg.GetDDNSParameters().DDNSReplaceClientName),
+			DdnsSendUpdates:            cfg.GetDDNSParameters().DDNSSendUpdates,
+			DdnsUpdateOnRenew:          cfg.GetDDNSParameters().DDNSUpdateOnRenew,
+			DdnsUseConflictResolution:  cfg.GetDDNSParameters().DDNSUseConflictResolution,
+			DdnsConflictResolutionMode: cfg.GetDDNSParameters().DDNSConflictResolutionMode,
+			DdnsTTLPercent:             cfg.GetDDNSParameters().DDNSTTLPercent,
 		},
 		KeaConfigHostnameCharParameters: models.KeaConfigHostnameCharParameters{
 			HostnameCharReplacement: storkutil.NullifyEmptyString(cfg.GetHostnameCharParameters().HostnameCharReplacement),
@@ -122,8 +124,8 @@ func (r *RestAPI) convertSubnetToRestAPI(sn *dbmodel.Subnet) *models.Subnet {
 					},
 				}
 				// DHCP options.
-				pool.KeaConfigPoolParameters.OptionsHash = poolDetails.DHCPOptionSetHash
-				pool.KeaConfigPoolParameters.Options = r.unflattenDHCPOptions(poolDetails.DHCPOptionSet, "", 0)
+				pool.KeaConfigPoolParameters.OptionsHash = poolDetails.DHCPOptionSet.Hash
+				pool.KeaConfigPoolParameters.Options = r.unflattenDHCPOptions(poolDetails.DHCPOptionSet.Options, "", 0)
 			}
 
 			localSubnet.Pools = append(localSubnet.Pools, pool)
@@ -170,14 +172,16 @@ func (r *RestAPI) convertSubnetToRestAPI(sn *dbmodel.Subnet) *models.Subnet {
 					RequireClientClasses: keaParameters.RequireClientClasses,
 				},
 				KeaConfigDdnsParameters: models.KeaConfigDdnsParameters{
-					DdnsGeneratedPrefix:       storkutil.NullifyEmptyString(keaParameters.DDNSGeneratedPrefix),
-					DdnsOverrideClientUpdate:  keaParameters.DDNSOverrideClientUpdate,
-					DdnsOverrideNoUpdate:      keaParameters.DDNSOverrideNoUpdate,
-					DdnsQualifyingSuffix:      storkutil.NullifyEmptyString(keaParameters.DDNSQualifyingSuffix),
-					DdnsReplaceClientName:     storkutil.NullifyEmptyString(keaParameters.DDNSReplaceClientName),
-					DdnsSendUpdates:           keaParameters.DDNSSendUpdates,
-					DdnsUpdateOnRenew:         keaParameters.DDNSUpdateOnRenew,
-					DdnsUseConflictResolution: keaParameters.DDNSUseConflictResolution,
+					DdnsGeneratedPrefix:        storkutil.NullifyEmptyString(keaParameters.DDNSGeneratedPrefix),
+					DdnsOverrideClientUpdate:   keaParameters.DDNSOverrideClientUpdate,
+					DdnsOverrideNoUpdate:       keaParameters.DDNSOverrideNoUpdate,
+					DdnsQualifyingSuffix:       storkutil.NullifyEmptyString(keaParameters.DDNSQualifyingSuffix),
+					DdnsReplaceClientName:      storkutil.NullifyEmptyString(keaParameters.DDNSReplaceClientName),
+					DdnsSendUpdates:            keaParameters.DDNSSendUpdates,
+					DdnsUpdateOnRenew:          keaParameters.DDNSUpdateOnRenew,
+					DdnsUseConflictResolution:  keaParameters.DDNSUseConflictResolution,
+					DdnsConflictResolutionMode: keaParameters.DDNSConflictResolutionMode,
+					DdnsTTLPercent:             keaParameters.DDNSTTLPercent,
 				},
 				KeaConfigFourOverSixParameters: models.KeaConfigFourOverSixParameters{
 					FourOverSixInterface:   storkutil.NullifyEmptyString(keaParameters.FourOverSixInterface),
@@ -304,13 +308,11 @@ func (r *RestAPI) convertSubnetFromRestAPI(restSubnet *models.Subnet) (*dbmodel.
 					PoolID: poolDetails.KeaConfigPoolParameters.PoolID,
 				}
 				// DHCP options.
-				pool.DHCPOptionSet, err = r.flattenDHCPOptions("", poolDetails.KeaConfigPoolParameters.Options, 0)
+				options, err := r.flattenDHCPOptions("", poolDetails.KeaConfigPoolParameters.Options, 0)
 				if err != nil {
 					return nil, err
 				}
-				if len(pool.DHCPOptionSet) > 0 {
-					pool.DHCPOptionSetHash = hasher.Hash(pool.DHCPOptionSet)
-				}
+				pool.SetDHCPOptions(options, hasher)
 			}
 			localSubnet.AddressPools = append(localSubnet.AddressPools, *pool)
 		}
@@ -352,14 +354,16 @@ func (r *RestAPI) convertSubnetFromRestAPI(restSubnet *models.Subnet) (*dbmodel.
 					RequireClientClasses: keaParameters.RequireClientClasses,
 				},
 				DDNSParameters: keaconfig.DDNSParameters{
-					DDNSGeneratedPrefix:       storkutil.NullifyEmptyString(keaParameters.DdnsGeneratedPrefix),
-					DDNSOverrideClientUpdate:  keaParameters.DdnsOverrideClientUpdate,
-					DDNSOverrideNoUpdate:      keaParameters.DdnsOverrideNoUpdate,
-					DDNSQualifyingSuffix:      storkutil.NullifyEmptyString(keaParameters.DdnsQualifyingSuffix),
-					DDNSReplaceClientName:     storkutil.NullifyEmptyString(keaParameters.DdnsReplaceClientName),
-					DDNSSendUpdates:           keaParameters.DdnsSendUpdates,
-					DDNSUpdateOnRenew:         keaParameters.DdnsUpdateOnRenew,
-					DDNSUseConflictResolution: keaParameters.DdnsUseConflictResolution,
+					DDNSGeneratedPrefix:        storkutil.NullifyEmptyString(keaParameters.DdnsGeneratedPrefix),
+					DDNSOverrideClientUpdate:   keaParameters.DdnsOverrideClientUpdate,
+					DDNSOverrideNoUpdate:       keaParameters.DdnsOverrideNoUpdate,
+					DDNSQualifyingSuffix:       storkutil.NullifyEmptyString(keaParameters.DdnsQualifyingSuffix),
+					DDNSReplaceClientName:      storkutil.NullifyEmptyString(keaParameters.DdnsReplaceClientName),
+					DDNSSendUpdates:            keaParameters.DdnsSendUpdates,
+					DDNSUpdateOnRenew:          keaParameters.DdnsUpdateOnRenew,
+					DDNSUseConflictResolution:  keaParameters.DdnsUseConflictResolution,
+					DDNSConflictResolutionMode: keaParameters.DdnsConflictResolutionMode,
+					DDNSTTLPercent:             keaParameters.DdnsTTLPercent,
 				},
 				FourOverSixParameters: keaconfig.FourOverSixParameters{
 					FourOverSixInterface:   storkutil.NullifyEmptyString(keaParameters.FourOverSixInterface),
