@@ -137,6 +137,10 @@ import { ParameterViewComponent } from './parameter-view/parameter-view.componen
 import { UncamelPipe } from './pipes/uncamel.pipe'
 import { UnhyphenPipe } from './pipes/unhyphen.pipe'
 import { SubnetsTableComponent } from './subnets-table/subnets-table.component'
+import { SharedNetworksTableComponent } from './shared-networks-table/shared-networks-table.component'
+import { KeaGlobalConfigurationViewComponent } from './kea-global-configuration-view/kea-global-configuration-view.component'
+import { KeaGlobalConfigurationFormComponent } from './kea-global-configuration-form/kea-global-configuration-form.component'
+import { PositivePipe } from './pipes/positive.pipe'
 
 /** Create the OpenAPI client configuration. */
 export function cfgFactory() {
@@ -226,6 +230,10 @@ export function cfgFactory() {
         UncamelPipe,
         UnhyphenPipe,
         SubnetsTableComponent,
+        SharedNetworksTableComponent,
+        KeaGlobalConfigurationViewComponent,
+        KeaGlobalConfigurationFormComponent,
+        PositivePipe,
     ],
     imports: [
         BrowserModule,
