@@ -1,4 +1,4 @@
-import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
+import { ComponentFixture, fakeAsync, TestBed, tick, waitForAsync } from '@angular/core/testing'
 
 import { DashboardComponent } from './dashboard.component'
 import { PanelModule } from 'primeng/panel'
@@ -23,12 +23,14 @@ import { HumanCountPipe } from '../pipes/human-count.pipe'
 import { SurroundPipe } from '../pipes/surround.pipe'
 import { EntityLinkComponent } from '../entity-link/entity-link.component'
 import { ServerSentEventsService, ServerSentEventsTestingService } from '../server-sent-events.service'
+import { SettingService } from '../setting.service'
 
 describe('DashboardComponent', () => {
     let component: DashboardComponent
     let fixture: ComponentFixture<DashboardComponent>
     let dhcpService: DHCPService
     let dataService: ServerDataService
+    let settingService: SettingService
 
     beforeEach(waitForAsync(() => {
         TestBed.configureTestingModule({
@@ -66,6 +68,7 @@ describe('DashboardComponent', () => {
 
         dhcpService = TestBed.inject(DHCPService)
         dataService = TestBed.inject(ServerDataService)
+        settingService = TestBed.inject(SettingService)
     }))
 
     beforeEach(() => {
@@ -95,6 +98,8 @@ describe('DashboardComponent', () => {
                     monitored: true,
                     name: 'dhcp4',
                     uptime: 3652,
+                    rps1: 1.5212,
+                    rps2: 0.3458,
                 },
             ],
             sharedNetworks4: {
@@ -200,6 +205,22 @@ describe('DashboardComponent', () => {
         expect(component).toBeTruthy()
     })
 
+    it('should fetch grafana url', fakeAsync(() => {
+        spyOn(settingService, 'getSettings').and.returnValue(
+            of({
+                grafanaUrl: 'http://localhost:3000',
+            } as any)
+        )
+
+        component.ngOnInit()
+        tick()
+        expect(component.grafanaUrl).toBe('http://localhost:3000')
+
+        fixture.detectChanges()
+        const grafanaIcons = fixture.debugElement.queryAll(By.css('i.pi-chart-line'))
+        expect(grafanaIcons?.length).toBe(1)
+    }))
+
     it('should indicate that HA is not enabled', () => {
         // This test doesn't check that the state is rendered correctly
         // as HTML, because the table listing daemons is dynamic and
@@ -422,4 +443,19 @@ describe('DashboardComponent', () => {
         expect(values).toContain('[41]')
         expect(values).toContain('')
     })
+
+    it('should display rps statistics', async () => {
+        await component.refreshDhcpOverview()
+        fixture.detectChanges()
+        await fixture.whenRenderingDone()
+
+        const table = fixture.debugElement.query(By.css('p-table'))
+        expect(table).toBeTruthy()
+
+        const rows = table.queryAll(By.css('tr'))
+        expect(rows.length).toBe(2)
+
+        expect(rows[1].nativeElement.innerText).toContain('1.52')
+        expect(rows[1].nativeElement.innerText).toContain('0.35')
+    })
 })
